@@ -3,7 +3,7 @@
    Copyright (C) 2020-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 0.4.1 (2021-05-29)
+   Version: 0.7.0 (2021-07-14)
    Website: http://www.gingerblue.org/
 
  */
@@ -18,7 +18,7 @@ int main_app (gint argc, gchar *argv[]) {
 	GingerblueData *gingerblue_config;
         GtkWindow *gingerblue_window;
 	gtk_init (&argc, &argv);
-        gingerblue_config = main_config ("LOCATIONS");
+        gingerblue_config = main_config ("studios.gingerblue.org");
 	gingerblue_window = gingerblue_main_loop (gingerblue_config);
 	gtk_widget_show_all (gingerblue_window);
 	gst_init(&argc, &argc);
