@@ -3,7 +3,7 @@
    Copyright (C) 2018-2021 Aamot Software
    Author(s): Ole Aamot <ole@gnome.org>
    License: GNU GPL version 3
-   Version: 0.4.1 (2021-05-29)
+   Version: 0.7.0 (2021-07-14)
    Website: http://www.gingerblue.org/
 
  */
@@ -42,7 +42,9 @@ GtkWidget *song_entry, *song_label;
 GtkWidget *instrument_entry, *instrument_label;
 GtkWidget *label_entry, *label_label;
 GtkWidget *line_entry, *line_label;
+GtkWidget *computer_entry, *computer_label;
 GtkWidget *recording_entry, *recording_label;
+GtkWidget *studio_entry, *studio_label;
 GtkWidget *summary_entry, *summary_label;
 
 GMainLoop *main_loops;
@@ -64,7 +66,8 @@ static void gb_assistant_button_clicked(GtkButton * button,
 					GtkAssistant * assistant)
 {
 	GstElement *src, *conv, *enc, *muxer, *sink, *recorder;
-
+	gchar *filename = NULL;
+	GDateTime *datestamp = g_date_time_new_now_utc ();
 	gst_element_send_event(recorder, gst_event_new_eos());
 
 	recorder = gst_pipeline_new("record_pipe");
@@ -74,10 +77,15 @@ static void gb_assistant_button_clicked(GtkButton * button,
 	enc = gst_element_factory_make("vorbisenc", "vorbis_enc");
 	muxer = gst_element_factory_make("oggmux", "oggmux");
 	sink = gst_element_factory_make("filesink", "sink");
-
+	filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
+			       gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
+			       gtk_entry_get_text(GTK_ENTRY(song_entry)), "_[",
+			       g_date_time_format_iso8601 (datestamp),
+			       "]",
+			       ".ogg", NULL);
 	g_object_set(G_OBJECT(sink), "location",
 		     g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC),
-				 "/", g_get_real_name(), " - ",
+				 "/", gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
 				 gtk_entry_get_text(GTK_ENTRY(song_entry)),
 				 ".ogg", NULL), NULL);
 
@@ -92,6 +100,7 @@ static void gb_assistant_button_clicked(GtkButton * button,
 	gst_element_set_state(recorder, GST_STATE_NULL);
 	g_main_loop_unref(main_loops);
 	gst_object_unref(GST_OBJECT(recorder));
+	g_date_time_unref (datestamp);
 }
 
 static void gb_assistant_cancel(GtkAssistant * assistant, gpointer data)
@@ -108,10 +117,12 @@ static void gb_assistant_cancel(GtkAssistant * assistant, gpointer data)
 static void gb_assistant_close(GtkAssistant * assistant, gpointer data)
 {
 	FILE *fp = NULL;
+	GDateTime *datestamp = g_date_time_new_now_utc ();
 	gchar *filename =
 	    g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
-			gtk_entry_get_text(GTK_ENTRY(musician_entry)), " - ",
-			gtk_entry_get_text(GTK_ENTRY(song_entry)),
+			gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
+			gtk_entry_get_text(GTK_ENTRY(song_entry)),  "_[",
+			g_date_time_format_iso8601 (datestamp), "]",
 			".gingerblue", NULL);
 	fp = fopen(filename, "w");
 	fprintf(fp, "<?xml version='1.0' encoding='UTF-8'?>\n");
@@ -126,12 +137,27 @@ static void gb_assistant_close(GtkAssistant * assistant, gpointer data)
 		gtk_entry_get_text(GTK_ENTRY(line_entry)));
 	fprintf(fp, "  <label>%s</label>\n",
 		gtk_entry_get_text(GTK_ENTRY(label_entry)));
+	fprintf(fp, "  <station>%s</station>\n",
+		gtk_entry_get_text(GTK_ENTRY(computer_entry)));
+	fprintf(fp, "  <filename>%s</filename>\n",
+		gtk_entry_get_text(GTK_ENTRY(recording_entry)));
+	fprintf(fp, "  <studio>%s</studio>\n",
+		gtk_entry_get_text(GTK_ENTRY(studio_entry)));
 	fprintf(fp, "</gingerblue>\n");
 	fclose(fp);
+	g_date_time_unref (datestamp);
 }
 
 static void gb_assistant_apply(GtkAssistant * assistant, gpointer data)
 {
+        GingerblueData *gingerblue_config;
+        GtkWindow *gingerblue_window;
+        /* gtk_init (&argc, &argv); */
+        gingerblue_config = main_config (gtk_entry_get_text(GTK_ENTRY(studio_entry)));
+        gingerblue_window = gingerblue_main_loop (gingerblue_config);
+        gtk_widget_show_all (gingerblue_window);
+        /* gst_init(&argc, &argc); */
+        /* gtk_main(); */
 	gst_element_send_event(data, gst_event_new_eos());
 }
 
@@ -149,6 +175,7 @@ int main(int argc, char **argv)
 	GstPlayer *player;
 	GstElement *src, *conv, *enc, *muxer, *sink, *pipeline;
 	GtkWidget *introduction;
+	GtkEntryBuffer *default_recording_title;
 	GtkWidget *entry, *label, *button, *progress, *hbox;
 	GtkWidget *summary_label, *summary_entry;
 	GtkWidget *gingerblue_main;
@@ -172,20 +199,27 @@ int main(int argc, char **argv)
 	GtkWidget *input_volume;
 	gdouble input_volume_value;
 	gint64 real_time;
-	PageInfo page[7] = {
+	PageInfo page[9] = {
 		{NULL, -1, "Gingerblue Setup", GTK_ASSISTANT_PAGE_INTRO, TRUE},
 		{NULL, -1, "Musician", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Song", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Instrument", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Input Line", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
 		{NULL, -1, "Label", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
-		{NULL, -1, "Recording", GTK_ASSISTANT_PAGE_CONFIRM, TRUE},
+		{NULL, -1, "Computer", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
+		{NULL, -1, "Recording", GTK_ASSISTANT_PAGE_CONTENT, TRUE},
+		{NULL, -1, "Studio", GTK_ASSISTANT_PAGE_CONFIRM, TRUE},
 	};
 	datestamp = g_date_time_new_now_utc ();
+	gchar *filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
+				      gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
+				      gtk_entry_get_text(GTK_ENTRY(song_entry)), "_[",
+				      g_date_time_format_iso8601 (datestamp), "]",
+				      ".ogg", NULL);
 	gtk_init(&argc, &argv);
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	introduction = gtk_assistant_new();
-	gtk_widget_set_size_request(GTK_WIDGET(introduction), 450, 300);
+	gtk_widget_set_size_request(GTK_WIDGET(introduction), 640, 480);
 	gtk_window_set_title(GTK_WINDOW(introduction), "GNOME Gingerblue");
 	g_signal_connect(G_OBJECT(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
@@ -193,7 +227,7 @@ int main(int argc, char **argv)
 	page[1].widget = gtk_box_new(FALSE, 5);
 	musician_label = gtk_label_new(_("Musician:"));
 	musician_entry = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(musician_entry), g_get_real_name());
+	if (g_strcmp0(musician_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(musician_entry), g_get_real_name()); else gtk_entry_set_text(GTK_ENTRY(musician_entry), gtk_entry_get_text(GTK_ENTRY(musician_entry)));
 	gtk_box_pack_start(GTK_BOX(page[1].widget), GTK_WIDGET(musician_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[1].widget), GTK_WIDGET(musician_entry),
@@ -201,7 +235,7 @@ int main(int argc, char **argv)
 	page[2].widget = gtk_box_new(FALSE, 5);
 	song_label = gtk_label_new(_("Song:"));
 	song_entry = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(song_entry), g_strconcat (_("Song - "), g_date_time_format_iso8601 (datestamp), NULL));
+	if (g_strcmp0(song_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(song_entry), g_strconcat (_("Song_-_"), g_date_time_format_iso8601 (datestamp), NULL)); else gtk_entry_set_text(GTK_ENTRY(song_entry), gtk_entry_get_text(GTK_ENTRY(song_entry)));
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(song_label),
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[2].widget), GTK_WIDGET(song_entry),
@@ -230,23 +264,50 @@ int main(int argc, char **argv)
 			   FALSE, FALSE, 5);
 	gtk_box_pack_start(GTK_BOX(page[5].widget), GTK_WIDGET(label_entry),
 			   FALSE, FALSE, 5);
+	page[6].widget = gtk_box_new(FALSE, 5);
+	computer_label = gtk_label_new(_("Computer:"));
+	computer_entry = gtk_entry_new();
+	gtk_entry_set_text(GTK_ENTRY(computer_entry), _(g_get_host_name()));
+	gtk_box_pack_start(GTK_BOX(page[6].widget), GTK_WIDGET(computer_label),
+			   FALSE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(page[6].widget), GTK_WIDGET(computer_entry),
+			   FALSE, FALSE, 5);
 	recording_label = gtk_button_new_with_label("Recording");
+	recording_entry = gtk_entry_new();
+	gtk_entry_set_text(GTK_ENTRY(recording_entry), g_strconcat(g_get_user_special_dir
+				     (G_USER_DIRECTORY_MUSIC), "/",
+				     gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
+				     gtk_entry_get_text(GTK_ENTRY(song_entry)),
+								   ".ogg", NULL));
 	g_signal_connect(G_OBJECT(recording_label), "clicked",
 			 G_CALLBACK(gb_record_cb),
 			 g_strconcat(g_get_user_special_dir
 				     (G_USER_DIRECTORY_MUSIC), "/",
-				     g_get_real_name(), " - ",
+				     gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
 				     gtk_entry_get_text(GTK_ENTRY(song_entry)),
 				     ".ogg", NULL));
-	page[6].widget = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(page[6].widget), g_strconcat(g_get_user_special_dir
+	page[7].widget = gtk_entry_new();
+	gtk_entry_set_text(GTK_ENTRY(page[7].widget), g_strconcat(g_get_user_special_dir
 								   (G_USER_DIRECTORY_MUSIC), "/",
-							           g_get_real_name(), " - ", gtk_entry_get_text(GTK_ENTRY(song_entry)), ".ogg", NULL));
-	gtk_box_pack_start(GTK_BOX(page[6].widget), GTK_WIDGET(recording_label),
+								  gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_", gtk_entry_get_text(GTK_ENTRY(song_entry)), ".ogg", NULL));
+	gtk_box_pack_start(GTK_BOX(page[7].widget), GTK_WIDGET(recording_label),
 			   FALSE, FALSE, 5);
-	for (i = 0; i < 7; i++) {
-	        page[i].index =
-		    gtk_assistant_append_page(GTK_ASSISTANT(introduction),
+	gtk_box_pack_start(GTK_BOX(page[7].widget), GTK_WIDGET(recording_entry),
+			   FALSE, FALSE, 5);
+	studio_label = gtk_button_new_with_label("Studio");
+	studio_entry = gtk_entry_new();
+	if (g_strcmp0(studio_entry, NULL)!=0) gtk_entry_set_text(GTK_ENTRY(studio_entry), "studio.gingerblue.org"); else gtk_entry_set_text(GTK_ENTRY(studio_entry), gtk_entry_get_text(GTK_ENTRY(studio_entry)));
+	g_signal_connect(G_OBJECT(studio_label), "clicked",
+			 G_CALLBACK(gb_assistant_apply),
+		         gtk_entry_get_text(GTK_ENTRY(studio_entry)));
+	page[8].widget = gtk_entry_new();
+	gtk_entry_set_text(GTK_ENTRY(page[8].widget), gtk_entry_get_text(GTK_ENTRY(studio_entry)));
+	gtk_box_pack_start(GTK_BOX(page[8].widget), GTK_WIDGET(studio_label),
+			   FALSE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(page[8].widget), GTK_WIDGET(studio_entry),
+			   FALSE, FALSE, 5);
+	for (i = 0; i < 9; i++) {
+	        page[i].index = gtk_assistant_append_page(GTK_ASSISTANT(introduction),
 					      GTK_WIDGET(page[i].widget));
 		gtk_assistant_set_page_title(GTK_ASSISTANT(introduction),
 					     GTK_WIDGET(page[i].widget),
@@ -333,13 +394,16 @@ int main(int argc, char **argv)
 	enc = gst_element_factory_make("vorbisenc", "vorbis_enc");
 	muxer = gst_element_factory_make("oggmux", "oggmux");
 	sink = gst_element_factory_make("filesink", "sink");
-
+	filename = g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC), "/",
+			       gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
+			       gtk_entry_get_text(GTK_ENTRY(song_entry)),"_[",
+			       g_date_time_format_iso8601 (datestamp), "]",
+			       ".ogg", NULL);
 	g_object_set(G_OBJECT(sink), "location",
 		     g_strconcat(g_get_user_special_dir(G_USER_DIRECTORY_MUSIC),
-				 "/", g_get_real_name(), " - ",
+				 "/", gtk_entry_get_text(GTK_ENTRY(musician_entry)), "_-_",
 				 gtk_entry_get_text(GTK_ENTRY(song_entry)),
 				 ".ogg", NULL), NULL);
-
 	gst_bin_add_many(GST_BIN(pipeline), src, conv, enc, muxer, sink, NULL);
 	gst_element_link_many(src, conv, enc, muxer, sink, NULL);
 
@@ -363,6 +427,7 @@ int main(int argc, char **argv)
 			 G_CALLBACK(gtk_main_quit), NULL);
 	g_signal_connect(GTK_WINDOW(introduction), "destroy",
 			 G_CALLBACK(gtk_main_quit), NULL);
+
 	/* g_free (gingerblue_data); */
 	/* play_free (player); */
 	g_date_time_unref (datestamp);
